@@ -25,6 +25,7 @@ from .type_defs import (
     GetAttendeeResponseTypeDef,
     GetMeetingResponseTypeDef,
     ListAttendeesResponseTypeDef,
+    MeetingFeaturesConfigurationTypeDef,
     NotificationsConfigurationTypeDef,
     TranscriptionConfigurationTypeDef,
 )
@@ -53,7 +54,7 @@ class Exceptions:
 
 class ChimeSDKMeetingsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html)
     """
 
@@ -71,7 +72,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Creates up to 100 attendees for an active Amazon Chime SDK meeting.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.batch_create_attendee)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.batch_create_attendee)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#batch_create_attendee)
         """
 
@@ -79,7 +80,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#can_paginate)
         """
 
@@ -89,7 +90,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Creates a new attendee for an active Amazon Chime SDK meeting.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.create_attendee)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.create_attendee)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#create_attendee)
         """
 
@@ -100,13 +101,14 @@ class ChimeSDKMeetingsClient(BaseClient):
         MediaRegion: str,
         ExternalMeetingId: str,
         MeetingHostId: str = ...,
-        NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...
+        NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...,
+        MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...
     ) -> CreateMeetingResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region with no
         initial attendees.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.create_meeting)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.create_meeting)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#create_meeting)
         """
 
@@ -118,13 +120,14 @@ class ChimeSDKMeetingsClient(BaseClient):
         ExternalMeetingId: str,
         Attendees: Sequence["CreateAttendeeRequestItemTypeDef"],
         MeetingHostId: str = ...,
+        MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...,
         NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...
     ) -> CreateMeetingWithAttendeesResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region, with
         attendees.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.create_meeting_with_attendees)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.create_meeting_with_attendees)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#create_meeting_with_attendees)
         """
 
@@ -133,7 +136,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         Deletes an attendee from the specified Amazon Chime SDK meeting and deletes
         their `JoinToken`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.delete_attendee)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.delete_attendee)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#delete_attendee)
         """
 
@@ -141,7 +144,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Deletes the specified Amazon Chime SDK meeting.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.delete_meeting)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.delete_meeting)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#delete_meeting)
         """
 
@@ -155,7 +158,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#generate_presigned_url)
         """
 
@@ -164,7 +167,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         Gets the Amazon Chime SDK attendee details for a specified meeting ID and
         attendee ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.get_attendee)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.get_attendee)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#get_attendee)
         """
 
@@ -172,7 +175,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Gets the Amazon Chime SDK meeting details for the specified meeting ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.get_meeting)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.get_meeting)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#get_meeting)
         """
 
@@ -182,7 +185,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Lists the attendees for the specified Amazon Chime SDK meeting.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.list_attendees)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.list_attendees)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#list_attendees)
         """
 
@@ -192,7 +195,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Starts transcription for the specified `meetingId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.start_meeting_transcription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.start_meeting_transcription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#start_meeting_transcription)
         """
 
@@ -200,6 +203,6 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
         Stops transcription for the specified `meetingId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.stop_meeting_transcription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.stop_meeting_transcription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client.html#stop_meeting_transcription)
         """
