@@ -15,6 +15,7 @@ import sys
 from typing import Dict, List, Sequence
 
 from .literals import (
+    MeetingFeatureStatusType,
     TranscribeLanguageCodeType,
     TranscribeMedicalRegionType,
     TranscribeMedicalSpecialtyType,
@@ -36,6 +37,7 @@ else:
 
 __all__ = (
     "AttendeeTypeDef",
+    "AudioFeaturesTypeDef",
     "BatchCreateAttendeeRequestRequestTypeDef",
     "BatchCreateAttendeeResponseTypeDef",
     "CreateAttendeeErrorTypeDef",
@@ -57,6 +59,7 @@ __all__ = (
     "ListAttendeesRequestRequestTypeDef",
     "ListAttendeesResponseTypeDef",
     "MediaPlacementTypeDef",
+    "MeetingFeaturesConfigurationTypeDef",
     "MeetingTypeDef",
     "NotificationsConfigurationTypeDef",
     "ResponseMetadataTypeDef",
@@ -75,6 +78,14 @@ AttendeeTypeDef = TypedDict(
     total=False,
 )
 
+AudioFeaturesTypeDef = TypedDict(
+    "AudioFeaturesTypeDef",
+    {
+        "EchoReduction": MeetingFeatureStatusType,
+    },
+    total=False,
+)
+
 BatchCreateAttendeeRequestRequestTypeDef = TypedDict(
     "BatchCreateAttendeeRequestRequestTypeDef",
     {
@@ -138,6 +149,7 @@ _OptionalCreateMeetingRequestRequestTypeDef = TypedDict(
     {
         "MeetingHostId": str,
         "NotificationsConfiguration": "NotificationsConfigurationTypeDef",
+        "MeetingFeatures": "MeetingFeaturesConfigurationTypeDef",
     },
     total=False,
 )
@@ -170,6 +182,7 @@ _OptionalCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
     "_OptionalCreateMeetingWithAttendeesRequestRequestTypeDef",
     {
         "MeetingHostId": str,
+        "MeetingFeatures": "MeetingFeaturesConfigurationTypeDef",
         "NotificationsConfiguration": "NotificationsConfigurationTypeDef",
     },
     total=False,
@@ -340,6 +353,14 @@ MediaPlacementTypeDef = TypedDict(
     total=False,
 )
 
+MeetingFeaturesConfigurationTypeDef = TypedDict(
+    "MeetingFeaturesConfigurationTypeDef",
+    {
+        "Audio": "AudioFeaturesTypeDef",
+    },
+    total=False,
+)
+
 MeetingTypeDef = TypedDict(
     "MeetingTypeDef",
     {
@@ -348,6 +369,7 @@ MeetingTypeDef = TypedDict(
         "ExternalMeetingId": str,
         "MediaRegion": str,
         "MediaPlacement": "MediaPlacementTypeDef",
+        "MeetingFeatures": "MeetingFeaturesConfigurationTypeDef",
     },
     total=False,
 )
